@@ -4,6 +4,7 @@ This module provides utility functions that support the AI provider implementati
 """
 
 import logging
+import os
 import time
 from functools import lru_cache
 from typing import Any
@@ -11,23 +12,35 @@ from typing import Any
 import tiktoken
 from halo import Halo
 
-from gac.constants import Utility
+from gac.constants import EnvDefaults, Utility
 from gac.errors import AIError
+from gac.providers import SUPPORTED_PROVIDERS
 
 logger = logging.getLogger(__name__)
 
 
+@lru_cache(maxsize=1)
+def _should_skip_tiktoken_counting() -> bool:
+    """Return True when token counting should avoid tiktoken calls entirely."""
+    value = os.getenv("GAC_NO_TIKTOKEN", str(EnvDefaults.NO_TIKTOKEN))
+    return value.lower() in ("true", "1", "yes", "on")
+
+
 def count_tokens(content: str | list[dict[str, str]] | dict[str, Any], model: str) -> int:
     """Count tokens in content using the model's tokenizer."""
     text = extract_text_content(content)
     if not text:
         return 0
 
+    if _should_skip_tiktoken_counting():
+        return len(text) // 4
+
     try:
         encoding = get_encoding(model)
         return len(encoding.encode(text))
     except Exception as e:
         logger.error(f"Error counting tokens: {e}")
+        # Fallback to rough estimation (4 chars per token on average)
         return len(text) // 4
 
 
@@ -45,10 +58,18 @@ def extract_text_content(content: str | list[dict[str, str]] | dict[str, Any]) -
 @lru_cache(maxsize=1)
 def get_encoding(model: str) -> tiktoken.Encoding:
     """Get the appropriate encoding for a given model."""
-    model_name = model.split(":")[-1] if ":" in model else model
+    provider, model_name = model.split(":", 1) if ":" in model else (None, model)
+
+    if provider != "openai":
+        return tiktoken.get_encoding(Utility.DEFAULT_ENCODING)
+
     try:
         return tiktoken.encoding_for_model(model_name)
     except KeyError:
+        # Fall back to default encoding if model not found
+        return tiktoken.get_encoding(Utility.DEFAULT_ENCODING)
+    except Exception:
+        # If there are any network/SSL issues, fall back to default encoding
         return tiktoken.get_encoding(Utility.DEFAULT_ENCODING)
 
 
@@ -94,31 +115,8 @@ def generate_with_retries(
     provider, model_name = model.split(":", 1)
 
     # Validate provider
-    supported_providers = [
-        "anthropic",
-        "cerebras",
-        "chutes",
-        "claude-code",
-        "deepseek",
-        "fireworks",
-        "gemini",
-        "groq",
-        "lm-studio",
-        "minimax",
-        "mistral",
-        "ollama",
-        "openai",
-        "openrouter",
-        "streamlake",
-        "synthetic",
-        "together",
-        "zai",
-        "zai-coding",
-        "custom-anthropic",
-        "custom-openai",
-    ]
-    if provider not in supported_providers:
-        raise AIError.model_error(f"Unsupported provider: {provider}. Supported providers: {supported_providers}")
+    if provider not in SUPPORTED_PROVIDERS:
+        raise AIError.model_error(f"Unsupported provider: {provider}. Supported providers: {SUPPORTED_PROVIDERS}")
 
     if not messages:
         raise AIError.model_error("No messages provided for AI generation")
