@@ -1,6 +1,6 @@
 """Configuration loading for gac.
 
-Handles environment variable and .env file precedence for application settings.
+Handles environment variable and .gac.env file precedence for application settings.
 """
 
 import os
@@ -12,19 +12,16 @@ from gac.constants import EnvDefaults, Logging
 
 
 def load_config() -> dict[str, str | int | float | bool | None]:
-    """Load configuration from $HOME/.gac.env, then ./.gac.env or ./.env, then environment variables."""
+    """Load configuration from $HOME/.gac.env, then ./.gac.env, then environment variables."""
     user_config = Path.home() / ".gac.env"
     if user_config.exists():
         load_dotenv(user_config)
 
-    # Check for both .gac.env and .env in project directory
+    # Check for .gac.env in project directory
     project_gac_env = Path(".gac.env")
-    project_env = Path(".env")
 
     if project_gac_env.exists():
         load_dotenv(project_gac_env, override=True)
-    elif project_env.exists():
-        load_dotenv(project_env, override=True)
 
     config = {
         "model": os.getenv("GAC_MODEL"),
@@ -37,6 +34,7 @@ def load_config() -> dict[str, str | int | float | bool | None]:
         in ("true", "1", "yes", "on"),
         "skip_secret_scan": os.getenv("GAC_SKIP_SECRET_SCAN", str(EnvDefaults.SKIP_SECRET_SCAN)).lower()
         in ("true", "1", "yes", "on"),
+        "no_tiktoken": os.getenv("GAC_NO_TIKTOKEN", str(EnvDefaults.NO_TIKTOKEN)).lower() in ("true", "1", "yes", "on"),
         "verbose": os.getenv("GAC_VERBOSE", str(EnvDefaults.VERBOSE)).lower() in ("true", "1", "yes", "on"),
         "system_prompt_path": os.getenv("GAC_SYSTEM_PROMPT_PATH"),
         "language": os.getenv("GAC_LANGUAGE"),
