@@ -91,19 +91,22 @@ def _configure_model(existing_env: dict[str, str]) -> bool:
         ("Gemini", "gemini-2.5-flash"),
         ("Groq", "meta-llama/llama-4-maverick-17b-128e-instruct"),
         ("LM Studio", "gemma3"),
-        ("MiniMax", "MiniMax-M2"),
+        ("MiniMax.io", "MiniMax-M2"),
         ("Mistral", "mistral-small-latest"),
         ("Ollama", "gemma3"),
-        ("OpenAI", "gpt-4.1-mini"),
+        ("OpenAI", "gpt-5-mini"),
         ("OpenRouter", "openrouter/auto"),
+        ("Replicate", "openai/gpt-oss-120b"),
         ("Streamlake", ""),
-        ("Synthetic", "hf:zai-org/GLM-4.6"),
+        ("Synthetic.new", "hf:zai-org/GLM-4.6"),
         ("Together AI", "openai/gpt-oss-20B"),
         ("Z.AI", "glm-4.5-air"),
         ("Z.AI Coding", "glm-4.6"),
     ]
     provider_names = [p[0] for p in providers]
-    provider = questionary.select("Select your provider:", choices=provider_names).ask()
+    provider = questionary.select(
+        "Select your provider:", choices=provider_names, use_shortcuts=True, use_arrow_keys=True, use_jk_keys=False
+    ).ask()
     if not provider:
         click.echo("Provider selection cancelled. Exiting.")
         return False
@@ -117,6 +120,11 @@ def _configure_model(existing_env: dict[str, str]) -> bool:
     is_custom_anthropic = provider_key == "custom-anthropic"
     is_custom_openai = provider_key == "custom-openai"
 
+    if provider_key == "minimaxio":
+        provider_key = "minimax"
+    elif provider_key == "syntheticnew":
+        provider_key = "synthetic"
+
     if is_streamlake:
         endpoint_id = _prompt_required_text("Enter the Streamlake inference endpoint ID (required):")
         if endpoint_id is None:
@@ -191,6 +199,9 @@ def _configure_model(existing_env: dict[str, str]) -> bool:
                     "Keep existing token",
                     "Re-authenticate (get new token)",
                 ],
+                use_shortcuts=True,
+                use_arrow_keys=True,
+                use_jk_keys=False,
             ).ask()
 
             if action is None or action.startswith("Keep existing"):
@@ -237,6 +248,9 @@ def _configure_model(existing_env: dict[str, str]) -> bool:
                 "Keep existing key",
                 "Enter new key",
             ],
+            use_shortcuts=True,
+            use_arrow_keys=True,
+            use_jk_keys=False,
         ).ask()
 
         if action is None:
@@ -290,6 +304,9 @@ def _configure_language(existing_env: dict[str, str]) -> None:
                 "Keep existing language",
                 "Select new language",
             ],
+            use_shortcuts=True,
+            use_arrow_keys=True,
+            use_jk_keys=False,
         ).ask()
 
         if action is None or action.startswith("Keep existing"):
