@@ -11,7 +11,7 @@ def call_openai_api(model: str, messages: list[dict], temperature: float, max_to
     """Call OpenAI API directly."""
     api_key = os.getenv("OPENAI_API_KEY")
     if not api_key:
-        raise AIError.model_error("OPENAI_API_KEY not found in environment variables")
+        raise AIError.authentication_error("OPENAI_API_KEY not found in environment variables")
 
     url = "https://api.openai.com/v1/chat/completions"
     headers = {"Authorization": f"Bearer {api_key}", "Content-Type": "application/json"}
@@ -29,6 +29,10 @@ def call_openai_api(model: str, messages: list[dict], temperature: float, max_to
             raise AIError.model_error("OpenAI API returned empty content")
         return content
     except httpx.HTTPStatusError as e:
+        if e.response.status_code == 429:
+            raise AIError.rate_limit_error(f"OpenAI API rate limit exceeded: {e.response.text}") from e
         raise AIError.model_error(f"OpenAI API error: {e.response.status_code} - {e.response.text}") from e
+    except httpx.TimeoutException as e:
+        raise AIError.timeout_error(f"OpenAI API request timed out: {str(e)}") from e
     except Exception as e:
         raise AIError.model_error(f"Error calling OpenAI API: {str(e)}") from e
